@@ -14,9 +14,6 @@
 
 #include "org_gnu_gconf_ConfSchema.h"
 
-#ifndef _Included_org_gnu_gconf_ConfSchema
-#define _Included_org_gnu_gconf_ConfSchema
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -270,4 +267,3 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gconf_ConfSchema_gconf_1schema_1get_1defa
 #ifdef __cplusplus
 }
 #endif
-#endif
